pub struct InverseFrequencyMaxIdf;Expand description
Inverse frequency weighting scheme for IDF. Compute log (1 + (max nt / nt))
where nt is the number of times a term appears in the corpus, and max nt
returns the most number of times any term appears in the corpus.